@@ -30,6 +30,7 @@ from sqlalchemy.sql import text
 import faraday.server.config
 from faraday.server.config import CONST_FARADAY_HOME_PATH, LOCAL_CONFIG_FILE, FARADAY_BASE
 from faraday.server.utils.database import is_unique_constraint_violation
+from faraday.utils.initdb import initdb_roles_and_permissions
 
 init()
 
@@ -103,13 +104,8 @@ class InitDB:
     def _create_roles(conn_string):
         engine = create_engine(conn_string)
         try:
-            statement = text(
-                "INSERT "
-                "INTO faraday_role(name, weight) "
-                "VALUES ('admin', 10),('asset_owner', 20),('pentester', 30),('client', 40);"
-            )
             connection = engine.connect()
-            connection.execute(statement)
+            initdb_roles_and_permissions(connection)
         except IntegrityError as ex:
             if is_unique_constraint_violation(ex):
                 # when re using database user could be created previously
@@ -292,7 +288,7 @@ class InitDB:
                 print(f"{Fore.YELLOW}WARNING{Fore.WHITE}: Can't create administrator user.")
                 raise
         if not already_created:
-            print(f"Admin user created with \n\n{Fore.RED}username: {Fore.WHITE}faraday \n "
+            print(f"Admin user created with \n\n{Fore.RED}username: {Fore.WHITE}faraday \n"
                   f"{Fore.RED}password:{Fore.WHITE} {user_password} \n")
 
     @staticmethod
