@@ -5,5 +5,7 @@ See the file 'doc/LICENSE' for the license information
 """
 # Related third party imports
 from flask_socketio import SocketIO
+from flask_celery import Celery
 
-socketio = SocketIO(path='/wsocket/v1')
+socketio = SocketIO(cors_allowed_origins='*', engineio_logger=True)
+celery = Celery()
