@@ -13,10 +13,12 @@ import itertools
 import unicodedata
 import uuid
 import time
+from uuid import uuid4
 
 import pytz
 from factory.fuzzy import (
     BaseFuzzyAttribute,
+    FuzzyAttribute,
     FuzzyChoice,
     FuzzyNaiveDateTime,
     FuzzyInteger,
@@ -46,6 +48,7 @@ from faraday.server.models import (
     Comment,
     CustomFieldsSchema,
     Agent,
+    AgentsSchedule,
     AgentExecution,
     SearchFilter,
     Executor,
@@ -53,7 +56,8 @@ from faraday.server.models import (
     Condition,
     Role,
     Workflow,
-    Pipeline
+    Pipeline,
+    VulnerabilityReference,
 )
 
 
@@ -164,7 +168,7 @@ class FuzzyIncrementalInteger(BaseFuzzyAttribute):
 
 
 class HostFactory(WorkspaceObjectFactory):
-    id = FuzzyIncrementalInteger(1, 65535)
+    # id = FuzzyIncrementalInteger(1, 65535)
     ip = FuzzyText()
     description = FuzzyText()
     os = FuzzyChoice(['Linux', 'Windows', 'OSX', 'Android', 'iOS'])
@@ -200,6 +204,14 @@ class ReferenceFactory(WorkspaceObjectFactory):
         sqlalchemy_session = db.session
 
 
+class VulnerabilityReferenceFactory(FaradayFactory):
+    name = FuzzyText()
+
+    class Meta:
+        model = VulnerabilityReference
+        sqlalchemy_session = db.session
+
+
 class ReferenceTemplateFactory(FaradayFactory):
     name = FuzzyText()
 
@@ -224,7 +236,8 @@ class ServiceFactory(WorkspaceObjectFactory):
     @classmethod
     def build_dict(cls, **kwargs):
         ret = super().build_dict(**kwargs)
-        ret['host'].workspace = kwargs['workspace']
+        if 'workspace' in kwargs:
+            ret['host'].workspace = kwargs['workspace']
         ret['parent'] = ret['host'].id
         ret['ports'] = [ret['port']]
         ret.pop('host')
@@ -399,15 +412,11 @@ class VulnerabilityTemplateFactory(FaradayFactory):
         return ret
 
 
-class CredentialFactory(HasParentHostOrService, WorkspaceObjectFactory):
-    host = factory.SubFactory(
-        HostFactory, workspace=factory.SelfAttribute('..workspace')
-    )
-    service = factory.SubFactory(
-        ServiceFactory, workspace=factory.SelfAttribute('..workspace')
-    )
+class CredentialFactory(WorkspaceObjectFactory):
     username = FuzzyText()
     password = FuzzyText()
+    endpoint = FuzzyText()
+    leak_date = factory.LazyFunction(lambda: datetime.datetime.now(datetime.timezone.utc).isoformat())
 
     class Meta:
         model = Credential
@@ -576,6 +585,33 @@ class ExecutorFactory(FaradayFactory):
         sqlalchemy_session = db.session
 
 
+class AgentScheduleFactory(FaradayFactory):
+    description = FuzzyText()
+    crontab = "5 * * * *"
+    timezone = 'UTC'
+    executor = factory.SubFactory(ExecutorFactory)
+    workspaces = factory.List([factory.SubFactory(WorkspaceFactory)])
+    creator = factory.SubFactory(UserFactory)
+
+    class Meta:
+        model = AgentsSchedule
+        sqlalchemy_session = db.session
+
+    @classmethod
+    def build_dict(cls, **kwargs):
+        ret = super().build_dict(**kwargs)
+        executor = ret.pop('executor')
+        workspaces = ret.pop('workspaces')
+        db.session.add(executor.agent)
+        db.session.add(executor)
+        for workspace in workspaces:
+            db.session.add(workspace)
+        db.session.commit()
+        ret['workspaces_names'] = [workspace.name for workspace in workspaces]
+        ret['executor_id'] = executor.id
+        return ret
+
+
 class AgentExecutionFactory(WorkspaceObjectFactory):
     executor = factory.SubFactory(
         ExecutorFactory,
@@ -588,6 +624,7 @@ class AgentExecutionFactory(WorkspaceObjectFactory):
         workspace=factory.SelfAttribute("..workspace"),
         end_date=None
     )
+    run_uuid = FuzzyAttribute(lambda: uuid4())
 
     class Meta:
         model = AgentExecution
